#!/usr/bin/python
#
# utility functions for RHN Configuration
# Copyright (c) 2002 Red Hat, Inc.
#  Distributed under GPL.
#
# Author: Adrian Likins <alikins@redhat.com>
#
#

import sys
import xmlrpclib
sys.path.append("/usr/share/rhn/register/")

import config
import rhnreg
import os
import string

cfg = config.RHNConfig()
cfg.load()

def getSystemId():
    path = "/etc/sysconfig/rhn/systemid"
    if not os.access(path, os.R_OK):
        return None
    
    f = open(path, "r")
    ret = f.read()
        
    f.close()
    return ret

def getServerUrls():
    # NOTE: this method talks to the current serverURL
    # setting to ask for a list of other available servers

    # see if we have a systemid
    systemid = getSystemId()
    s = rhnreg.getServer()
    returnList = []
    serverUrls = []
    try:
	if systemid:
            serverUrls = rhnreg.doCall(s.servers.list, systemid)
	else:
 	    serverUrls = rhnreg.doCall(s.servers.list)
    except xmlrpclib.Fault, f:
        if f.faultCode == -1:
            #this means were talking to a server that doesnt know this
            # call, shouldnt happen, but some satellites could do it
            print "this server does not implement the servers.list() call"
        else:
            # this is a little wrong... we tell the user there was a
            # fault, but keep on trucking...
            print """A xmlrpclib.fault was caught indicating there was
an error with the server. The error was: %s """ % f

        returnList = [cfg.readEntry("serverURL")]
    except rhnreg.CommunicationError:
	# we cant talk outsite the network yet, probabaly need
	# proxy stuff setup. 
	returnList = [cfg.readEntry("serverURL")]

    #serverUrls is a list of hashes

    # make sure we always list the master rhn server as per request
    masterserver = "xmlrpc.rhn.redhat.com"
    masterhandler = "/XMLRPC"
    # just to avoid dupes
    masterflag = 0
    defaultflag = 0

    defaultUrl = cfg.readEntry("serverURL")

    
    for i in serverUrls:
        if i['server'] == masterserver and i['handler'] == masterhandler:
            masterflag = 1
            
    if not masterflag:
        serverUrls.append({'server': masterserver, 'handler':masterhandler})

    for i in serverUrls:
        returnList.append( "https://%s/%s" % (i['server'], i['handler']) )

    if defaultUrl not in returnList:
        returnList.insert(0, defaultUrl)

    return returnList


def main():
        print getServerUrls()


if __name__ == "__main__":
    main()
